=================
rekishikon
=================
-------------------------------------------------
A simple, lightweight, language detection library
-------------------------------------------------

Simple Port of Nakatani Shuyo's Language Detection from Java to Python


With some fancy additions   

.. image:: https://travis-ci.com/K-Molloy/rekishikon.svg?branch=main
    :target: https://travis-ci.com/K-Molloy/rekishikon